<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>AboutPreferences</name>
    <message>
        <location filename="../src/ui/qml/AboutPreferences.qml" line="14"/>
        <source>Ricochet %1</source>
        <extracomment>%1 version, e.g. 1.0.0</extracomment>
        <translation>Ricochet %1</translation>
    </message>
</context>
<context>
    <name>AddContactDialog</name>
    <message>
        <location filename="../src/ui/qml/AddContactDialog.qml" line="51"/>
        <source>Share your Ricochet ID to allow connection requests</source>
        <translation>Udostępnij swój identyfikator Ricochet, aby umożliwić łączenie się z Tobą.</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/AddContactDialog.qml" line="107"/>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/AddContactDialog.qml" line="112"/>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
</context>
<context>
    <name>ContactActions</name>
    <message>
        <location filename="../src/ui/qml/ContactActions.qml" line="40"/>
        <source>Open Window</source>
        <translation>Otwórz okno</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactActions.qml" line="44"/>
        <source>Details...</source>
        <translation>Szczegóły...</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactActions.qml" line="48"/>
        <source>Rename</source>
        <translation>Zmień nazwę</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactActions.qml" line="53"/>
        <source>Remove</source>
        <translation>Usuń</translation>
    </message>
</context>
<context>
    <name>ContactIDField</name>
    <message>
        <location filename="../src/ui/qml/ContactIDField.qml" line="41"/>
        <source>&lt;b&gt;%1&lt;/b&gt; is already your contact</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; jest już w Twoich kontaktach</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactIDField.qml" line="43"/>
        <source>You can&apos;t add yourself as a contact</source>
        <translation>Nie możesz dodać siebie do kontaktów</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactIDField.qml" line="45"/>
        <source>Enter an ID starting with &lt;b&gt;ricochet:&lt;/b&gt;</source>
        <translation>Wpisz ID zaczynające się od &lt;b&gt;ricochet:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactIDField.qml" line="81"/>
        <source>Copied to clipboard</source>
        <translation>Skopiowano do schowka</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactIDField.qml" line="93"/>
        <source>Copy</source>
        <translation>Kopiuj</translation>
    </message>
</context>
<context>
    <name>ContactList</name>
    <message>
        <location filename="../src/ui/qml/ContactList.qml" line="76"/>
        <source>Online</source>
        <translation>Połączeni</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactList.qml" line="77"/>
        <source>Offline</source>
        <translation>Rozłączeni</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactList.qml" line="78"/>
        <source>Requests</source>
        <translation>Prośby o dodanie</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactList.qml" line="79"/>
        <source>Rejected</source>
        <translation>Odrzucone</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactList.qml" line="80"/>
        <source>Outdated</source>
        <translation>Przeterminowane</translation>
    </message>
</context>
<context>
    <name>ContactPreferences</name>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="98"/>
        <source>Date added:</source>
        <translation>Dołączył:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="106"/>
        <source>Last seen:</source>
        <translation>Ostatnio widziany:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="116"/>
        <source>Request:</source>
        <translation>Prośba o dodanie:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="126"/>
        <source>Pending connection</source>
        <translation>Oczekuje na połączenie</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="127"/>
        <source>Delivered</source>
        <translation>Dostarczony</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="128"/>
        <source>Accepted</source>
        <translation>Zaakceptowany</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="129"/>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="130"/>
        <source>Rejected</source>
        <translation>Odrzucony</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="134"/>
        <source>%1 (Connected)</source>
        <extracomment>%1 status, e.g. &quot;Accepted&quot;</extracomment>
        <translation>%1 (Połączony)</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="140"/>
        <source>Response:</source>
        <translation>Odpowiedź:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="163"/>
        <source>Rename</source>
        <translation>Zmień nazwę</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="170"/>
        <source>Remove</source>
        <translation>Usuń</translation>
    </message>
</context>
<context>
    <name>ContactRequestDialog</name>
    <message>
        <location filename="../src/ui/qml/ContactRequestDialog.qml" line="55"/>
        <source>Someone new is asking to connect to you</source>
        <translation>Ktoś chce się z Tobą skontaktować</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactRequestDialog.qml" line="102"/>
        <source>Reject</source>
        <translation>Odrzuć</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactRequestDialog.qml" line="107"/>
        <source>Accept</source>
        <translation>Akceptuj</translation>
    </message>
</context>
<context>
    <name>ContactRequestFields</name>
    <message>
        <location filename="../src/ui/qml/ContactRequestFields.qml" line="17"/>
        <source>ID:</source>
        <translation>ID:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactRequestFields.qml" line="29"/>
        <source>Name:</source>
        <translation>Nazwa:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactRequestFields.qml" line="40"/>
        <source>Message:</source>
        <translation>Wiadomość:</translation>
    </message>
</context>
<context>
    <name>GeneralPreferences</name>
    <message>
        <location filename="../src/ui/qml/GeneralPreferences.qml" line="13"/>
        <source>Use a single window for conversations</source>
        <translation>Używaj pojedynczego okno do rozmów</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/GeneralPreferences.qml" line="21"/>
        <source>Open links in default browser without prompting</source>
        <translation>Otwórz linki w domyślnej przeglądarce bez pytania</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/GeneralPreferences.qml" line="29"/>
        <source>Play audio notifications</source>
        <translation>Włącz powiadomienia dźwiękowe</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/GeneralPreferences.qml" line="38"/>
        <source>Volume</source>
        <translation>Głośność</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/GeneralPreferences.qml" line="53"/>
        <source>Language</source>
        <translation type="unfinished">Język</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/GeneralPreferences.qml" line="76"/>
        <source>Restart Ricochet to apply changes</source>
        <translation type="unfinished">Aby zaakceptować zmiany, uruchom Ricochet ponownie</translation>
    </message>
</context>
<context>
    <name>LanguagePreferences</name>
    <message>
        <source>Select Language</source>
        <translation type="vanished">Wybierz język</translation>
    </message>
    <message>
        <source>Restart Ricochet to apply changes</source>
        <translation type="vanished">Aby zaakceptować zmiany, uruchom Ricochet ponownie</translation>
    </message>
</context>
<context>
    <name>LanguagesModel</name>
    <message>
        <location filename="../src/ui/LanguagesModel.cpp" line="43"/>
        <source>System default</source>
        <translation>Domyślny w systemie</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../src/main.cpp" line="81"/>
        <source>Ricochet Error</source>
        <translation>Błąd programu Ricochet</translation>
    </message>
</context>
<context>
    <name>MainToolBar</name>
    <message>
        <location filename="../src/ui/qml/MainToolBar.qml" line="19"/>
        <source>Add Contact</source>
        <translation>Dodaj kontakt</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/MainToolBar.qml" line="28"/>
        <source>Preferences</source>
        <translation>Ustawienia</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/MainToolBar.qml" line="75"/>
        <source>Click to add contacts</source>
        <translation>Kliknij, aby dodać do kontaktów</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/ui/MainWindow.cpp" line="191"/>
        <source>Remove %1</source>
        <translation>Usuń %1</translation>
    </message>
    <message>
        <location filename="../src/ui/MainWindow.cpp" line="192"/>
        <source>Do you want to permanently remove %1?</source>
        <translation>Czy chcesz na stałe usunąć %1?</translation>
    </message>
</context>
<context>
    <name>MessageDelegate</name>
    <message>
        <location filename="../src/ui/qml/MessageDelegate.qml" line="26"/>
        <source>%1 is offline</source>
        <extracomment>%1 nickname</extracomment>
        <translation>%1 jest rozłączony</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/MessageDelegate.qml" line="135"/>
        <source>Copy ID</source>
        <translation>Skopiuj ID</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/MessageDelegate.qml" line="135"/>
        <source>Copy Link</source>
        <translation>Skopiuj link</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/MessageDelegate.qml" line="140"/>
        <source>Open with Browser</source>
        <translation>Otwórz w przeglądarce</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/MessageDelegate.qml" line="154"/>
        <source>Add as Contact</source>
        <translation>Dodaj jako kontakt</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/MessageDelegate.qml" line="166"/>
        <source>Copy Message</source>
        <translation>Kopiuj wiadomość</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/MessageDelegate.qml" line="173"/>
        <source>Copy Selection</source>
        <translation>Kopiuj zaznaczenie</translation>
    </message>
</context>
<context>
    <name>MessageDialogWrapper</name>
    <message>
        <location filename="../src/ui/qml/MessageDialogWrapper.qml" line="8"/>
        <source>Remove %1</source>
        <translation>Usuń %1</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/MessageDialogWrapper.qml" line="10"/>
        <source>Do you want to permanently remove %1?</source>
        <extracomment>%1 nickname</extracomment>
        <translation>Czy chcesz na stałe usunąć %1?</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/MessageDialogWrapper.qml" line="11"/>
        <source>This contact will no longer be able to message you, and will be notified about the removal. They may choose to send a new connection request.</source>
        <translation>Ten kontakt nie będzie mógł więcej wysyłać do Ciebie wiadomości i zostanie poinformowany o usunięciu. Może wysłać Ci nową prośbę o połączenie.</translation>
    </message>
</context>
<context>
    <name>NetworkSetupWizard</name>
    <message>
        <location filename="../src/ui/qml/NetworkSetupWizard.qml" line="100"/>
        <source>This computer&apos;s Internet connection is free of obstacles. I would like to connect directly to the Tor network.</source>
        <translation>Połączenie internetowe tego kompuera jest wolne od przeszkód. Chcę połączyć się bezpośrednio z siecią Tor.</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/NetworkSetupWizard.qml" line="107"/>
        <source>Connect</source>
        <translation>Połącz</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/NetworkSetupWizard.qml" line="124"/>
        <source>This computer&apos;s Internet connection is censored, filtered, or proxied. I need to configure network settings.</source>
        <translation>Połączenie internetowe tego komputera jest cenzurowane, filtrowane lub trasowane przez serwer proxy. Muszę skonfigurować ustawienia sieciowe.</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/NetworkSetupWizard.qml" line="131"/>
        <source>Configure</source>
        <translation>Konfiguruj</translation>
    </message>
</context>
<context>
    <name>OfflineStateItem</name>
    <message>
        <location filename="../src/ui/qml/OfflineStateItem.qml" line="107"/>
        <source>Configure</source>
        <translation>Konfiguruj</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/OfflineStateItem.qml" line="115"/>
        <source>Details</source>
        <translation>Szczegóły</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/OfflineStateItem.qml" line="143"/>
        <source>Connection failed</source>
        <translation>Połączenie nie powiodło się</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/OfflineStateItem.qml" line="169"/>
        <source>Connecting…</source>
        <extracomment>\u2026 is ellipsis</extracomment>
        <translation>Łączenie…</translation>
    </message>
</context>
<context>
    <name>OpenBrowserDialog</name>
    <message>
        <location filename="../src/ui/qml/OpenBrowserDialog.qml" line="40"/>
        <source>&lt;b&gt;Warning!&lt;/b&gt; Opening links with your default browser will harm your security and anonymity.&lt;br&gt;&lt;br&gt;You can &lt;a href=&apos;.&apos;&gt;copy to the clipboard&lt;/a&gt; instead.</source>
        <translation>&lt;b&gt;Uwaga!&lt;/b&gt; Otwieranie linków za pomocą domyślnej przeglądarki spowoduje utratę bezpieczeństwa i anonimowości. Zamiast tego możesz &lt;a href=&apos;.&apos;&gt;skopiować go do schowka&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/OpenBrowserDialog.qml" line="59"/>
        <source>Don&apos;t ask again for links from %1</source>
        <translation>Nie pytaj ponownie dla linków od %1</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/OpenBrowserDialog.qml" line="65"/>
        <source>Don&apos;t ask again for any links (not recommended!)</source>
        <translation>Nigdy nie pytaj ponownie (niezalecane!)</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/OpenBrowserDialog.qml" line="72"/>
        <source>Open Browser</source>
        <translation>Otwórz przeglądarkę</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/OpenBrowserDialog.qml" line="84"/>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../src/ui/qml/PreferencesDialog.qml" line="12"/>
        <source>Ricochet Preferences</source>
        <translation>Ustawienia Ricocheta</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/PreferencesDialog.qml" line="41"/>
        <source>General</source>
        <translation>Główne</translation>
    </message>
    <message>
        <source>Language</source>
        <translation type="vanished">Język</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/PreferencesDialog.qml" line="46"/>
        <source>Contacts</source>
        <translation>Kontakty</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/PreferencesDialog.qml" line="51"/>
        <source>Tor</source>
        <translation>Tor</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/PreferencesDialog.qml" line="56"/>
        <source>About</source>
        <translation>O programie</translation>
    </message>
</context>
<context>
    <name>QCocoaMenuItem</name>
    <message>
        <location filename="../src/ui/qml/MainWindow.qml" line="29"/>
        <source>Preference</source>
        <translation>Ustawienie</translation>
    </message>
</context>
<context>
    <name>StartupStatusPage</name>
    <message>
        <location filename="../src/ui/qml/StartupStatusPage.qml" line="18"/>
        <source>The Tor process was not started successfully. This is most likely an installation or system error.</source>
        <translation>Tor nie został uruchomiony poprawnie. Najprawdopodobniej oznacza to błąd instalacji lub systemu.</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/StartupStatusPage.qml" line="49"/>
        <source>Quit</source>
        <translation>Wyjdź</translation>
    </message>
</context>
<context>
    <name>TorBootstrapStatus</name>
    <message>
        <location filename="../src/ui/qml/TorBootstrapStatus.qml" line="17"/>
        <source>Connecting to the Tor network…</source>
        <extracomment>\u2026 is ellipsis</extracomment>
        <translation>Łączenie z siecią Tor…</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorBootstrapStatus.qml" line="51"/>
        <source>Back</source>
        <translation>Wróć</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorBootstrapStatus.qml" line="58"/>
        <source>Hide details</source>
        <translation>Ukryj szczegóły</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorBootstrapStatus.qml" line="58"/>
        <source>Show details</source>
        <translation>Pokaż szczegóły</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorBootstrapStatus.qml" line="70"/>
        <source>Done</source>
        <translation>Zrobione</translation>
    </message>
</context>
<context>
    <name>TorConfigurationPage</name>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="73"/>
        <source>Does this computer need a proxy to access the internet?</source>
        <translation>Czy ten komputer potrzebuje serwera proxy, aby łączyć się z Internetem?</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="85"/>
        <source>Proxy type:</source>
        <translation>Typ proxy:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="90"/>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="92"/>
        <source>None</source>
        <translation>Brak</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="107"/>
        <source>Address:</source>
        <translation>Adres:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="116"/>
        <source>IP address or hostname</source>
        <translation>Adres IP lub nazwa hosta</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="119"/>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="130"/>
        <source>Username:</source>
        <translation>Nazwa użytkownika:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="140"/>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="150"/>
        <source>Optional</source>
        <translation>Opcjonalny</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="143"/>
        <source>Password:</source>
        <translation>Hasło:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="160"/>
        <source>Does this computer&apos;s Internet connection go through a firewall that only allows connections to certain ports?</source>
        <translation>Czy połączenie internetowe tego komputera jest kierowane przez firewall, który pozwala na łączenie się tylko z wybranymi portami?</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="171"/>
        <source>Allowed ports:</source>
        <translation>Dozwolone porty:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="178"/>
        <source>Example: 80,443</source>
        <translation>Na przykład: 80,443</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="189"/>
        <source>If this computer&apos;s Internet connection is censored, you will need to obtain and use bridge relays.</source>
        <translation>Jeżeli połączenie internetowe tego komputera jest cenzurowane, będziesz musiał uzyskać dostęp do węzła pośredniego (&lt;i&gt;bridge relay&lt;/i&gt;).</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="198"/>
        <source>Enter one or more bridge relays (one per line):</source>
        <translation>Podaj jeden lub więcej węzłów pośrednich (jeden w linii):</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="213"/>
        <source>Back</source>
        <translation>Wróć</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="220"/>
        <source>Connect</source>
        <translation>Połącz</translation>
    </message>
</context>
<context>
    <name>TorPreferences</name>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="25"/>
        <source>Running:</source>
        <translation>Uruchomione:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="26"/>
        <location filename="../src/ui/qml/TorPreferences.qml" line="28"/>
        <location filename="../src/ui/qml/TorPreferences.qml" line="30"/>
        <source>Yes</source>
        <translation>Tak</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="26"/>
        <location filename="../src/ui/qml/TorPreferences.qml" line="28"/>
        <location filename="../src/ui/qml/TorPreferences.qml" line="30"/>
        <source>No</source>
        <translation>Nie</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="26"/>
        <source>External</source>
        <translation>Zewnętrzny</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="27"/>
        <source>Control connected:</source>
        <translation>Połączony z portem kontrolnym:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="29"/>
        <source>Circuits established:</source>
        <translation>Obwody utworzone:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="31"/>
        <source>Hidden service:</source>
        <translation>Ukryte usługi:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="32"/>
        <source>Online</source>
        <translation>Połączony</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="32"/>
        <source>Offline</source>
        <translation>Rozłączony</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="33"/>
        <source>Version:</source>
        <translation>Wersja:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="60"/>
        <source>Error: &lt;b&gt;%1&lt;/b&gt;</source>
        <extracomment>%1 is error message</extracomment>
        <translation>Błąd: &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="76"/>
        <source>Configure</source>
        <translation>Konfiguruj</translation>
    </message>
</context>
<context>
    <name>TorStateWidget</name>
    <message>
        <location filename="../src/ui/qml/TorStateWidget.qml" line="9"/>
        <location filename="../src/ui/qml/TorStateWidget.qml" line="20"/>
        <source>Connection failed</source>
        <translation>Połączenie nie powiodło się</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorStateWidget.qml" line="12"/>
        <location filename="../src/ui/qml/TorStateWidget.qml" line="22"/>
        <source>Connecting…</source>
        <extracomment>\u2026 is ellipsis</extracomment>
        <translation>Łączenie…</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorStateWidget.qml" line="25"/>
        <source>Connecting… (%1%)</source>
        <extracomment>%1 is progress percentage, e.g. 100</extracomment>
        <translation>Łączenie… (%1%)</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorStateWidget.qml" line="32"/>
        <source>Online</source>
        <translation>Połączony</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorStateWidget.qml" line="34"/>
        <source>Connected</source>
        <translation>Połączony</translation>
    </message>
</context>
</TS>
